@@ -35,6 +35,24 @@ class DockerClient(docker.Client):
 
         return socket
 
-    def replace_container(self, container_id, config):
+    def replace_container(self, container_id, *args, **kwargs):
+        config = self._container_config(*args, **kwargs)
         u = self._url("/containers/create?replaceContainer={0}".format(container_id))
         return self._result(self._post_json(u, config), json=True)
+
+    def logs(self, container):
+        if isinstance(container, dict):
+            container = container.get('Id')
+        params = {
+            'logs': 1,
+            'stdout': 1,
+            'stderr': 1
+        }
+        socket = self.attach_websocket(container, params)
+        out = []
+        while True:
+            c = socket.recv()
+            if c is None:
+                break
+            out.append(c)
+        return ''.join(out)
